pub fn mint_into_success<T, AccountId>()where
T: Mutate<AccountId>,
<T as Inspect<AccountId>>::Balance: AtLeast8BitUnsigned + Debug,
AccountId: AtLeast8BitUnsigned,Expand description
Test Mutate::mint_into for successful token minting.
It ensures that account balances and total issuance values are updated correctly after minting tokens into two distinct accounts.